==> haskell-th-abstraction-0.2.6.0-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-abstraction.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-abstraction
version: 0.2.6.0
id: th-abstraction-0.2.6.0-8bhBYrrqrAJFCd9hjMrFb4
key: th-abstraction-0.2.6.0-8bhBYrrqrAJFCd9hjMrFb4
license: ISC
copyright: 2017 Eric Mertens
maintainer: emertens@gmail.com
author: Eric Mertens
homepage: https://github.com/glguy/th-abstraction
synopsis: Nicer interface for reified information about data types
description:
    This package normalizes variations in the interface for
    inspecting datatype information via Template Haskell
    so that packages and support a single, easier to use
    informational datatype while supporting many versions
    of Template Haskell.
category: Development
abi: 033d711d7c9638e8bcc2f49549e04787
exposed: True
exposed-modules:
    Language.Haskell.TH.Datatype
hidden-modules: Language.Haskell.TH.Datatype.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/th-abstraction-0.2.6.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/th-abstraction-0.2.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/th-abstraction-0.2.6.0
hs-libraries: HSth-abstraction-0.2.6.0-8bhBYrrqrAJFCd9hjMrFb4
depends:
    base-4.11.1.0 ghc-prim-0.5.2.0 template-haskell-2.13.0.0
    containers-0.5.11.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
haddock-interfaces: /usr/share/doc/haskell-th-abstraction/html/th-abstraction.haddock
haddock-html: /usr/share/doc/haskell-th-abstraction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-abstraction-0.2.7.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-abstraction.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-abstraction
version: 0.2.7.0
id: th-abstraction-0.2.7.0-K3VY5rzhCFL2FVEMFfolof
key: th-abstraction-0.2.7.0-K3VY5rzhCFL2FVEMFfolof
license: ISC
copyright: 2017 Eric Mertens
maintainer: emertens@gmail.com
author: Eric Mertens
homepage: https://github.com/glguy/th-abstraction
synopsis: Nicer interface for reified information about data types
description:
    This package normalizes variations in the interface for
    inspecting datatype information via Template Haskell
    so that packages and support a single, easier to use
    informational datatype while supporting many versions
    of Template Haskell.
category: Development
abi: e161720940186da8d7d7f15cc4c214a9
exposed: True
exposed-modules:
    Language.Haskell.TH.Datatype
hidden-modules: Language.Haskell.TH.Datatype.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/th-abstraction-0.2.7.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/th-abstraction-0.2.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/th-abstraction-0.2.7.0
hs-libraries: HSth-abstraction-0.2.7.0-K3VY5rzhCFL2FVEMFfolof
depends:
    base-4.11.1.0 ghc-prim-0.5.2.0 template-haskell-2.13.0.0
    containers-0.5.11.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
haddock-interfaces: /usr/share/doc/haskell-th-abstraction/html/th-abstraction.haddock
haddock-html: /usr/share/doc/haskell-th-abstraction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
